@@ -3,27 +3,24 @@ package Number::Phone::JP::Table::Class2;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
-# Table last modified: 2007-02-01
+# Table last modified: 2008-01-15
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '09120'  => '\d+', # ブラステル
     '09121'  => '\d+', # ブラステル
-    '09122'  => '\d+', # イクアント
-    '09123'  => '\d+', # イクアント
     '09130'  => '\d+', # ドコモ
-    '09144'  => '\d+', # アルファーネットワーク
-    '09145'  => '\d+', # アルファーネットワーク
-    '09155'  => '\d+', # エヌ・ティ・ティ・エムイー
-    '09156'  => '\d+', # エヌ・ティ・ティ・エムイー
-    '09177'  => '\d+', # BBテクノロジー
+    '09144'  => '\d+', # アルフゼネットワーク
+    '09145'  => '\d+', # アルフゼネットワーク
+    '09155'  => '\d+', # NTT-ME
+    '09156'  => '\d+', # NTT-ME
+    '09177'  => '\d+', # ソフトバンクBB
     '09180'  => '\d+', # スピーディア
     '09181'  => '\d+', # 関西コムネット
-    '09188'  => '\d+', # トライネットワークインターナショナル
     '09191'  => '\d+', # ぷららネットワークス
     '09192'  => '\d+', # ぷららネットワークス
-    '09198'  => '\d+', # BBテクノロジー
+    '09198'  => '\d+', # ソフトバンクBB
     '09199'  => '\d+', # エヌティティエムイー中国
 );
 
